read_line

Function read_line 

pub fn read_line() -> Result<String, Error>
Reads a line from stdin with echo enabled (normal terminal input). The returned string does not include the trailing newline. Returns an error if the input is not valid UTF-8.