pub fn read_password() -> Result<String, Error>Expand description
Reads a password from stdin without echoing it to the terminal.
The returned string does not include the trailing newline.
Returns an error if the input is not valid UTF-8.
Mimics the behaviour of Go’s golang.org/x/term.ReadPassword.